@@ -665,18 +665,18 @@ sub validator_for {
     return sub {
         return 1 if $handler->($_[0]);
 
-        $value_desc = _complete_desc($value_desc, $_[0]);
-        croak qq{\u$value_desc}
-            . ($value_desc =~ /\s$/ ? q{} : q{ })
+        my $desc = _complete_desc($value_desc, $_[0]);
+        croak qq{\u$desc}
+            . ($desc =~ /\s$/ ? q{} : q{ })
             . qq{is not of type $typename};
     } if !@constraints;
 
     return sub {
         # Either the type matches or we die...
         if (!$handler_for{$typename}($_[0])) {
-            $value_desc = _complete_desc($value_desc, $_[0]);
-            croak qq{\u$value_desc}
-                . ($value_desc =~ /\s$/ ? q{} : q{ })
+            my $desc = _complete_desc($value_desc, $_[0]);
+            croak qq{\u$desc}
+                . ($desc =~ /\s$/ ? q{} : q{ })
                 . qq{is not of type $typename};
         }
         return 1 if !@constraints;
@@ -687,10 +687,10 @@ sub validator_for {
 
             # If it fails to match...
             if (! eval{ local $SIG{__WARN__} = sub{}; $test->(local $_ = $_[0]) }) {
-                $value_desc = _complete_desc($value_desc, $_[0]);
-                my $constraint_desc = _describe_constraint($_[0], $value_desc, $test, $@);
-                croak qq{\u$value_desc}
-                    . ($value_desc =~ /\s$/ ? q{} : q{ })
+                my $desc = _complete_desc($value_desc, $_[0]);
+                my $constraint_desc = _describe_constraint($_[0], $desc, $test, $@);
+                croak qq{\u$desc}
+                    . ($desc =~ /\s$/ ? q{} : q{ })
                     . qq{did not satisfy the constraint: $constraint_desc\n }
             }
         }
